@@ -19,7 +19,7 @@ from rest_framework.status import HTTP_400_BAD_REQUEST, HTTP_401_UNAUTHORIZED
 from rest_framework_simplejwt.exceptions import InvalidToken, TokenError
 from rest_framework_simplejwt.serializers import TokenObtainPairSerializer, TokenRefreshSerializer
 from rest_framework_simplejwt.tokens import RefreshToken
-from badi_utils.dynamic_api import DynamicModelApi, InCaseSensitiveTokenObtainPairSerializer
+from badi_utils.dynamic_api import DynamicModelApi, InCaseSensitiveTokenObtainPairSerializer, CustomValidation
 from badi_utils.logging import log
 from badi_utils.responses import ResponseOk, ResponseNotOk
 from badi_utils.utils import random_with_N_digits, permissions_json
@@ -29,7 +29,6 @@ from badi_user.api.serializers import UserSerializer, GroupSerializer, MemberSer
 from badi_user.filter import UserListFilter, MemberListFilter, LogFilter
 from badi_user.models import Token, Log
 from django.utils.translation import gettext_lazy as _
-from badi_utils.sms import IpPanelSms
 from django.contrib.auth import get_user_model
 from django.conf import settings
 
@@ -52,8 +51,8 @@ class UserViewSet(DynamicModelApi):
     }
     switches = {
         'is_active': {
-            'true': ' ',
-            'false': ' ',
+            'true': '/api/v1/user/change_state/0',
+            'false': '/api/v1/user/change_state/0',
         }
     }
 
@@ -81,9 +80,12 @@ class UserViewSet(DynamicModelApi):
     @action(methods=['put'], detail=False, url_path='change_state/(?P<pk>[^/.]+)')
     def change_state(self, request, pk, *args, **kwargs):
         user = User.objects.get(pk=pk)
+        if user.is_superuser or user == self.request.user:
+            raise CustomValidation('user', _('You are not allowed to disable this user!'))
         user.is_active = not user.is_active
         user.save()
-
+        log(self.request.user, 3, 4, True,
+            text=f'User {user.__str__()} {"Activated" if user.is_active else "Disabled"}!')
         return JsonResponse({
             'message': 'با موفقیت {0} شد'.format('فعال' if user.is_active else 'غیرفعال')
         })
@@ -180,7 +182,7 @@ class LoginAuth:
         serializer = TokenObtainPairSerializer(data=request.data)
         try:
             serializer.is_valid(raise_exception=True)
-            username = request.data.get('username')
+            username = request.data.get('username', '').strip()
             dashboard_login = request.data.get('dashboard_login')
             user = User.objects.filter(username=username).first()
             if user.is_superuser:
@@ -244,6 +246,8 @@ class AuthViewSet(viewsets.ViewSet, LoginAuth):
                 return Response({'email': ['Invalid mobile number']},
                                 status=status.HTTP_400_BAD_REQUEST)
         serializer.is_valid(raise_exception=True)
+        if hasattr(User, 'user_register_create_validate'):
+            User.user_register_create_validate(self.request.data)
         if config.get('code-required'):
             token = self.request.data.get('token')
             last_token = Token.objects.filter(phone=mobile_number, is_accepted=False, is_forgot=False).last()
@@ -274,6 +278,8 @@ class AuthViewSet(viewsets.ViewSet, LoginAuth):
                 user.username = username
                 user.mobile_number = mobile_number
                 user.token = last_token
+                if hasattr(User, 'set_user_custom_data_register'):
+                    user = User.set_user_custom_data_register(self.request, user)
                 user.save()
                 if BADI_AUTH_CONFIG['login'].get('login_to_django'):
                     login(request, user)
@@ -398,40 +404,34 @@ class AuthViewSet(viewsets.ViewSet, LoginAuth):
 
     @action(methods=['post'], detail=False)
     def forgot_password(self, req, *args, **kwargs):
-        mobile_number = self.request.data.get('mobile_number')
-        user = User.objects.filter(mobile_number=mobile_number).first()
+        config = BADI_AUTH_CONFIG['forgot']
+        mobile_email = self.request.data.get(config.get('user_find_key'))
+        user = User.objects.filter(**{config.get('user_find_key'): mobile_email}).first()
         if not user:
-            return JsonResponse({'mobile_number': ['کاربری با شماره تماس وارد شده وجود ندارد!']},
+            return JsonResponse({config.get('user_find_key'): [_('There is no user with this specifications!')]},
                                 status=HTTP_400_BAD_REQUEST)
+        HTTP_ORIGIN = config.get('site_url') or req.META.get('HTTP_ORIGIN')
+        if user.token and user.token.is_enabled():
+            return JsonResponse({'mobile_number': ['شما به تازگی درخواست داده اید!']},
+                                status=HTTP_400_BAD_REQUEST)
+        hash_code = ''.join(random.choice(string.ascii_letters + string.digits) for x in range(10))
+        token = Token()
+        token.phone = user.mobile_number
+        token.last_send = datetime.datetime.now()
+        token.is_forgot = True
+        token.token = hash_code
+        token.save()
+        user.token = token
+        user.save()
+        token_id_hash = token.pk * 8569 - 1330
+        text = f'{HTTP_ORIGIN}/forgot_password/{token_id_hash}/{hash_code}'
+        print(f'لینک تغییر رمز عبور: %0D%0A {text}')
 
-        phone_number = self.request.data.get('mobile_number')
-        HTTP_ORIGIN = req.META.get('HTTP_ORIGIN')
-        if phone_number and len(phone_number) == 11:
-            user = User.objects.filter(mobile_number=phone_number).first()
-            if user:
-                if user.token and user.token.is_enabled():
-                    return JsonResponse({'mobile_number': ['شما به تازگی درخواست داده اید!']},
-                                        status=HTTP_400_BAD_REQUEST)
-                hash_code = ''.join(random.choice(string.ascii_letters + string.digits) for x in range(30))
-                token = Token()
-                token.user = user
-                token.last_send = datetime.datetime.now()
-                token.is_forgot = True
-                token.token = hash_code
-                token.save()
-                user.token = token
-                user.save()
-                token_id_hash = token.pk * 8569 - 1330
-                text = f'{HTTP_ORIGIN}/forgot_password/{token_id_hash}/{hash_code}'
-                print(f'لینک تغییر رمز عبور: %0D%0A {text}')
-                Sms.link(user.mobile_number, token_id_hash, hash_code)
-                return ResponseOk({})
-
-            else:
-                return JsonResponse({'mobile_number': ['کاربری با شماره تماس وارد شده وجود ندارد!']},
-                                    status=HTTP_400_BAD_REQUEST)
-
-        return JsonResponse({'mobile_number': ['مشکلی پیش آمده است!']}, status=HTTP_400_BAD_REQUEST)
+        attr = getattr(user, config.get('user_find_key'))
+        if hasattr(user.mobile_number, 'national_number'):
+            attr = '0' + str(user.mobile_number.national_number)
+        config.get('class')(attr).send_forgot_link(token_id_hash, hash_code)
+        return ResponseOk({})
 
     @action(methods=['post'], detail=False)
     def refresh(self, request, *args, **kwargs):
