@@ -20,6 +20,7 @@ from rest_framework_simplejwt.tokens import RefreshToken
 from .logging import log
 from .dynamic_models import custom_change_date
 from django.contrib.auth import get_user_model
+from django.utils.translation import gettext_lazy as _
 
 User = get_user_model()
 
@@ -38,13 +39,51 @@ def replace_star(key, dictionary):
     return dictionary
 
 
-class DynamicModelApi(viewsets.ModelViewSet, BaseDatatableView):
+class ViewSetPermission:
     permission_classes = [permissions.IsAuthenticated]
     custom_perms = {}
+    permission_required = None
+
+    def check_permissions(self, request):
+        request_user = self.request.user
+        if request_user.is_authenticated:
+            request_user.update_action()
+            if request_user.is_admin:
+                return True
+        if self.custom_perms:
+            if self.custom_perms.get(self.action) is None:
+                if request_user.is_authenticated and request_user.is_admin:
+                    return True
+                else:
+                    self.permission_denied(
+                        request, message=getattr('Login Required', 'message', None)
+                    )
+
+            elif self.custom_perms.get(self.action) is False:
+                return True
+
+            elif self.custom_perms.get(self.action) is True and request_user.is_authenticated:
+                return True
+
+            elif self.custom_perms.get(self.action) is True and not request_user.is_authenticated:
+                self.permission_denied(
+                    request, message=getattr('Login Required', 'message', None)
+                )
+            elif self.custom_perms.get(self.action) and not request_user.has_perm(
+                    self.custom_perms.get(self.action)):
+                self.permission_denied(
+                    request, message=getattr('Login Required', 'message', None)
+                )
+        else:
+            self.permission_denied(
+                request, message=getattr('Login Required', 'message', None)
+            )
+
+
+class DynamicModelApi(ViewSetPermission, viewsets.ModelViewSet, BaseDatatableView):
     model = None
     columns = None
     order_columns = None
-    permission_required = None
     disables_views = []
     ordering_field = None
     switches = None
@@ -129,41 +168,6 @@ class DynamicModelApi(viewsets.ModelViewSet, BaseDatatableView):
         dump = json.dumps(response, cls=LazyEncoder)
         return self.render_to_response(dump)
 
-    def check_permissions(self, request):
-        request_user = self.request.user
-        if request_user.is_authenticated:
-            request_user.update_action()
-            if request_user.is_admin:
-                return True
-        if self.custom_perms:
-            if self.custom_perms.get(self.action) is None:
-                if request_user.is_authenticated and request_user.is_admin:
-                    return True
-                else:
-                    self.permission_denied(
-                        request, message=getattr('Login Required', 'message', None)
-                    )
-
-            elif self.custom_perms.get(self.action) is False:
-                return True
-
-            elif self.custom_perms.get(self.action) is True and request_user.is_authenticated:
-                return True
-
-            elif self.custom_perms.get(self.action) is True and not request_user.is_authenticated:
-                self.permission_denied(
-                    request, message=getattr('Login Required', 'message', None)
-                )
-            elif self.custom_perms.get(self.action) and not request_user.has_perm(
-                    self.custom_perms.get(self.action)):
-                self.permission_denied(
-                    request, message=getattr('Login Required', 'message', None)
-                )
-        else:
-            self.permission_denied(
-                request, message=getattr('Login Required', 'message', None)
-            )
-
     def create(self, request, *args, **kwargs):
         if 'create' in self.disables_views:
             return Http404()
@@ -438,16 +442,16 @@ def api_error_creator(model, error_fields: list, extra=None, required_fields=Non
         if field.attname.replace('_id', '') in error_fields:
             response[field.attname.replace('_id', '')] = {"error_messages":
                 {
-                    "blank": "{0} را وارد کنید!".format(field.verbose_name),
-                    "required": "{0} را وارد کنید!".format(field.verbose_name),
-                    "invalid": "{0} وارد شده صحیح نمی باشد!".format(field.verbose_name),
-                    "invalid_choice": "{0} وارد شده صحیح نمی باشد!".format(field.verbose_name),
-                    "invalid_pk_value": "{0} وارد شده صحیح نمی باشد!".format(field.verbose_name),
-                    "incorrect_type": "{0} وارد شده صحیح نمی باشد!".format(field.verbose_name),
-                    "does_not_exist": "{0} وارد شده صحیح نمی باشد!".format(field.verbose_name),
-                    "null": "{0} را وارد کنید!".format(field.verbose_name),
-                    "empty": "{0} را وارد کنید!".format(field.verbose_name),
-                    "unique": "این {0} قبلا ثبت شده است!".format(field.verbose_name)
+                    "blank": _("enter {0}!").format(field.verbose_name),
+                    "required": _("{0} is required!").format(field.verbose_name),
+                    "invalid": _("invalid {0}!").format(field.verbose_name),
+                    "invalid_choice": _("invalid choice for {0}!").format(field.verbose_name),
+                    "invalid_pk_value": _("invalid {0}!").format(field.verbose_name),
+                    "incorrect_type": _("invalid {0}!").format(field.verbose_name),
+                    "does_not_exist": _("invalid {0}!").format(field.verbose_name),
+                    "null": _("enter {0}!").format(field.verbose_name),
+                    "empty": _("enter {0}!").format(field.verbose_name),
+                    "unique": _("this {0} already submitted!").format(field.verbose_name),
                 },
             }
             if field.attname.replace('_id', '') in required_fields:
