@@ -34,8 +34,8 @@ class ZPBankAction:
         baseUrl = request._request.META.get('HTTP_ORIGIN') if request._request.META.get(
             'HTTP_ORIGIN') else BaseUrl
         amount = int(amount) * 10
-        if amount < 10000:
-            raise CustomValidation('amount', 'حداقل مبلغ قابل شارژ 10,000 تومان می باشد')
+        if amount < 100:
+            raise CustomValidation('amount', 'حداقل مبلغ قابل شارژ 100 تومان می باشد')
 
         req_data = {
             "merchant_id": MERCHANT,
@@ -77,7 +77,7 @@ class ZPBankAction:
         t_status = request.GET.get('Status')
         t_authority = request.GET.get('Authority')
         trans = BankTransaction.objects.filter(authority=t_authority).first()
-        if not trans or t_authority:
+        if not trans or not t_authority:
             return ResponseNotOk(reason={
                 'error': self.bankError})
         if t_status == 'OK':
@@ -105,7 +105,7 @@ class ZPBankAction:
                     trans.message = req.json()['data']['message']
                     trans.save()
                     return ResponseNotOk(reason={
-                        'error': req.json()['errors']['message']})
+                        'error': req.json()['errors']['message'] if req.json()['errors'] else ''})
                 else:
                     return ResponseNotOk(reason={
                         'error': self.bankError})
@@ -145,7 +145,7 @@ class ZPBankAction:
                     if not Transaction.objects.filter(bank_transaction=trans).first():
                         transAction = Transaction(
                             user=trans.user,
-                            amount=trans.amount,
+                            amount=trans.amount / 10,
                             type='+',
                             subject=_("Charge"),
                             bank_transaction=trans,
